betty.project.extension.http_api_doc package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.project.extension.http_api_doc package

## Module contents

Integrate Betty with Swagger UI.

final class betty.project.extension.http_api_doc.HttpApiDoc

  Bases: `ShorthandPluginBase`, `EntryPointProvider`

  Provide user-friendly HTTP API documentation.

  classmethod assets_directory_path() → Path

    Return the path on disk where the extension’s assets are located.

    This may be anywhere in your Python package.

  classmethod depends_on() → set[PluginIdentifier[Extension]]

    The plugins this one depends on.

  webpack_entry_point_cache_keys() → Sequence[str]

    Get the keys that make a Webpack build for this provider unique.

    Providers that can be cached regardless may `return ()`.

  classmethod webpack_entry_point_directory_path() → Path

    Get the path to the directory with the entry point assets.

    The directory must include at least a `package.json` and `main.ts`.